#[repr(C)]pub struct nrf_modem_dect_phy_config_params {
pub band_group_index: u8,
pub harq_rx_process_count: u8,
pub harq_rx_expiry_time_us: u32,
}Expand description
DECT PHY configuration parameters.
Fields
band_group_index: u8Band group index.
Allowed values: 0 or 1. Value 0 refers to RF frequencies operating near 2GHz and value 1 to RF frequencies near 1 GHz.
harq_rx_process_count: u8Number of HARQ processes.
The HARQ reception buffer is divided equally between processes. Supported values: 1, 2, 4, 8.
harq_rx_expiry_time_us: u32HARQ RX buffer expiry time, in microseconds.
A HARQ process soft buffer allocation is released when there have been no receptions to that buffer within the buffer’s expiry time.
Maximum supported value: 5000000.