nrf_modem_dect_phy_link_config_params

Struct nrf_modem_dect_phy_link_config_params 

#[repr(C)]
pub struct nrf_modem_dect_phy_link_config_params { pub primary_link_id: nrf_modem_dect_phy_link_id, pub secondary_link_count: u8, pub secondary_link_ids: __IncompleteArrayField<nrf_modem_dect_phy_link_id>, }
Link configuration parameters.

Fields

primary_link_id: nrf_modem_dect_phy_link_id

Primary link.

The modem tracks the frequency of the primary link for Automatic Frequency Control purposes. This frequency is propagated down the tree, that is, the Radio Device uses this frequency for all its radio operations except those directed to secondary links.

secondary_link_count: u8

Number of secondary links.

secondary_link_ids: __IncompleteArrayField<nrf_modem_dect_phy_link_id>

Secondary links.

The modem tracks the frequency of secondary links for Automatic Frequency Control purposes. When communicating with a secondary link the modem compensates the frequency difference between the secondary link and the primary link.