#[repr(C)]pub struct nrf_modem_dect_phy_rssi_event {
pub handle: u32,
pub meas_start_time: u64,
pub carrier: u16,
pub meas_len: u16,
pub meas: *mut i8,
}Expand description
RSSI measurement event.
Fields
handle: u32Handle of the operation.
meas_start_time: u64Measurement start time, in modem time units.
carrier: u16The absolute channel frequency number on which the measurements were made.
meas_len: u16Number of measurements in @ref meas.
meas: *mut i8RSSI measurements, in dBm.
If a symbol is measured, its measurement is in the interval [-140, -1]. If the measurement is saturated, the measured signal strength is reported as a positive integer. If a symbol is not measured, its value is reported as @ref NRF_MODEM_DECT_PHY_RSSI_NOT_MEASURED.