nrf_modem_dect_phy_rx_params

Struct nrf_modem_dect_phy_rx_params 

#[repr(C)]
pub struct nrf_modem_dect_phy_rx_params { pub start_time: u64, pub handle: u32, pub network_id: u32, pub mode: nrf_modem_dect_phy_rx_mode, pub rssi_interval: nrf_modem_dect_phy_rssi_interval, pub link_id: nrf_modem_dect_phy_link_id, pub rssi_level: i8, pub carrier: u16, pub duration: u32, pub filter: nrf_modem_dect_phy_rx_filter, }
RX operation.

Fields

start_time: u64

Operation start time as modem time.

If zero, the operation will be executed immediately.

This kind of scheduling can only be done when the modem is idle.

handle: u32

Handle for the operation.

An application-defined handle for the operation.

network_id: u32

Network ID for scrambling.

Can be zero if receiving only beacons.

mode: nrf_modem_dect_phy_rx_mode

Reception mode.

rssi_interval: nrf_modem_dect_phy_rssi_interval

RSSI measurement reporting interval, in slots.

link_id: nrf_modem_dect_phy_link_id

Radio link identifier.

Set to @ref NRF_MODEM_DECT_PHY_LINK_UNSPECIFIED if expecting to receive from any Radio Device within the primary network (either the primary link or any downlink device).

Set to the link id of a secondary link if expecting to receive over that link.

rssi_level: i8

Expected antenna signal level of the reception.

Values in range [-128, -1] are dBm values for the expected reception level.

Value 0 is interpreted as MAC having no knowledge of the expected level. This initiates a fast AGC algorithm that tries to adjust the reception gain level based on the received signal level.

If the duration of the RX operation is long enough to receive multiple slots, this value will only be used for the first successful reception. Subsequent receptions during the same RX operation are initiated using a level that has been adjusted based on the previous successful reception (slow AGC).

carrier: u16

The absolute channel frequency number for the reception.

See 5.4.2 of @ref DECT-SPEC “DECT-2020 NR Part 2”.

duration: u32

Duration of reception in modem time units.

filter: nrf_modem_dect_phy_rx_filter

Reception filter for this operation.