#[repr(C)]pub struct nrf_modem_dect_phy_tx_rx_params {
pub tx: nrf_modem_dect_phy_tx_params,
pub rx: nrf_modem_dect_phy_rx_params,
}Expand description
Combined TX and RX operation.
Fields
tx: nrf_modem_dect_phy_tx_paramsTX operation.
rx: nrf_modem_dect_phy_rx_paramsRX operation.
The start time of the RX operation is relative to the end of the TX operation and it must include the guard time.