nrf_modem_dect_phy_tx_rx_params

Struct nrf_modem_dect_phy_tx_rx_params 

#[repr(C)]
pub struct nrf_modem_dect_phy_tx_rx_params { pub tx: nrf_modem_dect_phy_tx_params, pub rx: nrf_modem_dect_phy_rx_params, }
Combined TX and RX operation.

Fields

tx: nrf_modem_dect_phy_tx_params

TX operation.

rx: nrf_modem_dect_phy_rx_params

RX operation.

The start time of the RX operation is relative to the end of the TX operation and it must include the guard time.